from setuptools import setup,find_packages
setup(
    name = "qiye-game1",
    version = "0.1.2",
    author = "qiye",
    #url = "qiyenull.github.io",
    description = "孤独终老 --邓海林",
    packages = find_packages("qiye"),
    package_dir = {"":"qiye"},
    package_data = {
        "":[".txt", ".info", "*.properties", ".py"],
        "":["data/*.*"],
    },
    exclude = ["*.test", "*.test.*", "test.*", "test"]

)



def get_info():
    n = 40
    q = 5
    index = q

    print("*"*n)
    for i in range(q):
        if i == q//2:
            str = "qiye is so boring!"
            p = len(str)
            print("*"*(i+1) + " "*((n-q-1)//4) + str + " "*((n-q-1)//4) + "*"*index)
        else:
            print("*"*(i+1) + " "*(n-q-1) + "*"*index)
        index -= 1
    print("*"*n)
